# LineBreakParagraphNode


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------

## Example

```python
from src.client.generated.models.line_break_paragraph_node import LineBreakParagraphNode

# TODO update the JSON string below
json = "{}"
# create an instance of LineBreakParagraphNode from a JSON string
line_break_paragraph_node_instance = LineBreakParagraphNode.from_json(json)
# print the JSON string representation of the object
print(LineBreakParagraphNode.to_json())

# convert the object into a dict
line_break_paragraph_node_dict = line_break_paragraph_node_instance.to_dict()
# create an instance of LineBreakParagraphNode from a dict
line_break_paragraph_node_from_dict = LineBreakParagraphNode.from_dict(line_break_paragraph_node_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


